package com.yidian.shenghuoquan.buserorder.viewmodel

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import com.yidian.bcommon.mvvm.BaseViewModel
import com.yidian.bcommon.utils.CPointUtils
import com.yidian.shenghuoquan.buserorder.dto.OrderDetailDto
import com.yidian.shenghuoquan.buserorder.http.OrderRemoteDataSource
import com.yidian.shenghuoquan.buserorder.http.callback.IGetOrderDetailCallback
import org.json.JSONObject
import timber.log.Timber

/**
 * author: yinjiacheng
 * date: 2021/8/21 09:31
 * description: 订单详情页
 */
class OrderDetailViewModel : BaseViewModel() {

  private val _orderDetailData = MutableLiveData<OrderDetailDto?>()
  val orderDetailData: LiveData<OrderDetailDto?> = _orderDetailData

  /**
   * 请求订单详情
   */
  fun requestOrderDetail(orderId: String) {
    OrderRemoteDataSource.getOrderDetail(object : IGetOrderDetailCallback {
      override fun getOrderDetailSuccess(result: OrderDetailDto?) {
        _orderDetailData.value = result
      }

      override fun getOrderDetailFailure(message: String?) {
        _orderDetailData.value = null
      }
    }, hashMapOf("order_id" to orderId, "business_from" to "2"))
  }

  /**
   * 页面曝光埋点
   */
  fun commitExposePageBuriedPoint() {
    // 埋点数据包装
    val jsonObject = JSONObject()
    jsonObject.put("eventName", "EXPOSE_PAGE")
    val contextJsonObject = JSONObject()
    contextJsonObject.put("page", "ORDER_DETAIL_PAGE")
    jsonObject.put("contextMap", contextJsonObject)
    val propertiesJsonObject = JSONObject()
    propertiesJsonObject.put("event_id", "SHQNG_R_1632389947033")
    jsonObject.put("propertiesMap", propertiesJsonObject)
    jsonObject.put("logType", 1)
    CPointUtils.performCommitLog(jsonObject)
    Timber.tag("BUserOrderBuriedPoint").d("commit order detail page log: $jsonObject")
  }

  /**
   * 按钮点击埋点
   */
  fun commitClickWidgetBuriedPoint(widgetName: String) {
    // 埋点数据包装
    val jsonObject = JSONObject()
    jsonObject.put("eventName", "CLICK_WIDGET")
    val contextJsonObject = JSONObject()
    contextJsonObject.put("page", "ORDER_DETAIL_PAGE")
    jsonObject.put("contextMap", contextJsonObject)
    val entitiesJsonObject = JSONObject()
    val widgetInfoJsonObject = JSONObject()
    widgetInfoJsonObject.put("widget_type", "BUTTON")
    widgetInfoJsonObject.put("widget_name", widgetName)
    entitiesJsonObject.put("widget_info", widgetInfoJsonObject)
    jsonObject.put("entitiesMap", entitiesJsonObject)
    val propertiesJsonObject = JSONObject()
    propertiesJsonObject.put("event_id", "SHQNG_R_1632389997706")
    jsonObject.put("propertiesMap", propertiesJsonObject)
    jsonObject.put("logType", 1)
    CPointUtils.performCommitLog(jsonObject)
    Timber.tag("BUserOrderBuriedPoint").d("commit order detail widget log: $jsonObject")
  }
}
